@@ -27,22 +27,11 @@ It was written by Pabs.
 
 
 
-/* System headers */
-
-#include <stdio.h>
-#include <unistd.h>
-/* #include <math.h> */
-
-
-
 /* Local headers */
 
 #include "common.h"
 
-/* For Windows/DOS */
-#ifndef F_OK
-	#define F_OK 0
-#endif
+
 
 bool exists(char* fname){
 	return !access(fname,F_OK);
@@ -152,6 +141,10 @@ SRINT get_SRINT( BYTE** byte, int* bit, BYTE s, BYTE r ){
 			case 5: mask = 0x3f; break;
 			case 6: mask = 0x7f; break;
 			case 7: mask = 0xff; break;
+                        default:
+                                mask = 0xff;
+                                fputs( "chmdeco: warning: impossible condition found reading s/r int\n", stderr );
+                        break;
 		}
 		mask <<= base;
 		ret = ( ret << (num_bits+1) ) | (SRINT)((**byte & mask) >> base);
