@@ -27,14 +27,6 @@ It was written by Pabs.
 
 
 
-/* System headers */
-
-#include <sys/types.h>
-#include <string.h>
-#include <time.h>
-
-
-
 /* Local headers */
 
 #include "common.h"
@@ -258,7 +250,7 @@ void print_with_entity_refs( FILE* f, char* str ){
 			case 0x99: fputs( "&trade;", f ); break;
 			case 0: return;
 			default:
-				fprintf( stderr, "%s: %s\n", PROGNAME, "buggy implementation of strcspn detected" );
+				fprintf( stderr, "%s: %s\n", PACKAGE, "buggy implementation of strcspn detected" );
 				fputc( *(s+l), f );
 		}
 		s += l+1;
