@@ -27,24 +27,13 @@ It was written by Pabs.
 
 
 
-/* System headers */
-
-#include <stdio.h>
-#include <sys/types.h>
-#include <errno.h>
-#include <stdlib.h>
-#include <string.h>
-#include <unistd.h>
-
-
-
 /* Local headers */
 
 #include "chmdeco.h"
 #include "common.h"
 #include "convert.h"
 #include "sitemap.h"
-#include "strings.h"
+#include "strings_file.h"
 #include "hhc.h"
 
 
@@ -89,10 +78,10 @@ void recreate_hhc( void ){
 				FrameName = get_string( get_DWORD(b+0x24) );
 				WindowName = get_string( get_DWORD(b+0x28) );
 			} else
-				fprintf( stderr, "%s: %s/%s: %s\n", PROGNAME, input, "#IDXHDR", strerror(errno) );
+				fprintf( stderr, "%s: %s/%s: %s\n", PACKAGE, input, "#IDXHDR", strerror(errno) );
 			FCLOSE( idxhdr );
 		} else if( errno && errno != ENOENT )
-			fprintf( stderr, "%s: %s/%s: %s\n", PROGNAME, input, "#IDXHDR", strerror(errno) );
+			fprintf( stderr, "%s: %s/%s: %s\n", PACKAGE, input, "#IDXHDR", strerror(errno) );
 
 		fputs(SITEMAP_HEADER,hhc);
 
@@ -159,17 +148,17 @@ void recreate_hhc( void ){
 					close_sitemap();
 				}
 			} else
-				fprintf( stderr, "%s: %s/%s: %s\n", PROGNAME, input, "#TOCIDX", strerror(errno) );
+				fprintf( stderr, "%s: %s/%s: %s\n", PACKAGE, input, "#TOCIDX", strerror(errno) );
 			FCLOSE( tocidx );
 		} else if( errno && errno != ENOENT )
-			fprintf( stderr, "%s: %s/%s: %s\n", PROGNAME, input, "#TOCIDX", strerror(errno) );
+			fprintf( stderr, "%s: %s/%s: %s\n", PACKAGE, input, "#TOCIDX", strerror(errno) );
 
 		fputs( SITEMAP_FOOTER, hhc );
 
 		FCLOSE( hhc );
 
 	} else
-		fprintf( stderr, "%s: %s/%s/%s: %s\n", PROGNAME, input, "#recreated", cf, strerror(errno) );
+		fprintf( stderr, "%s: %s/%s/%s: %s\n", PACKAGE, input, "#recreated", cf, strerror(errno) );
 
 	/* Nothing useful */
 	if( !got_valid_prop && !got_tree ){
@@ -223,7 +212,7 @@ bool print_tree( void ){
 					}
 				} else {
 					next = 0;
-					fprintf( stderr, "%s: %s/%s: %s\n", PROGNAME, input, "#TOCIDX", strerror(errno) );
+					fprintf( stderr, "%s: %s/%s: %s\n", PACKAGE, input, "#TOCIDX", strerror(errno) );
 				}
 			}
 
@@ -231,7 +220,7 @@ bool print_tree( void ){
 			if(next) fseek(tocidx,next,SEEK_SET);
 
 		} else {
-			fprintf( stderr, "%s: %s/%s: %s\n", PROGNAME, input, "#TOCIDX", strerror(errno) );
+			fprintf( stderr, "%s: %s/%s: %s\n", PACKAGE, input, "#TOCIDX", strerror(errno) );
 			break;
 		}
 
