@@ -27,16 +27,6 @@ It was written by Pabs.
 
 
 
-/* System headers */
-
-#include <stdio.h>
-#include <sys/types.h>
-#include <stdlib.h>
-#include <string.h>
-#include <errno.h>
-
-
-
 /* Local headers */
 
 #include "chmdeco.h"
@@ -74,7 +64,7 @@ void recreate_hhk( void ){
 		do{
 
 			if( !fread(block,12,1,btree) ){
-				fprintf( stderr, "%s: %s/%s: %s\n", PROGNAME, input, "$WWKeywordLinks/BTree", strerror(errno) );
+				fprintf( stderr, "%s: %s/%s: %s\n", PACKAGE, input, "$WWKeywordLinks/BTree", strerror(errno) );
 				break;
 			}
 
@@ -101,7 +91,7 @@ void recreate_hhk( void ){
 					if( !hhk ){
 						hhk = recreate( inf );
 						if( !hhk ){
-							fprintf( stderr, "%s: %s/%s/%s: %s\n", PROGNAME, input, "#recreated", inf, strerror(errno) );
+							fprintf( stderr, "%s: %s/%s/%s: %s\n", PACKAGE, input, "#recreated", inf, strerror(errno) );
 							close_sitemap(); FREE(Name); FCLOSE( btree ); return;
 						}
 
@@ -153,7 +143,7 @@ void recreate_hhk( void ){
 						uint topici;
 						for(topici=0; topici < num_topics && space_left > free_space; topici++){
 							if( !read_DWORD( btree, &index ) ){
-								fprintf( stderr, "%s: %s/%s/%s: %s\n", PROGNAME, input, "#recreated", inf, strerror(errno) );
+								fprintf( stderr, "%s: %s/%s/%s: %s\n", PACKAGE, input, "#recreated", inf, strerror(errno) );
 								FCLOSE(hhk); FCLOSE( btree ); return;
 							}
 							print_topics_entry(hhk,index);
@@ -168,7 +158,7 @@ void recreate_hhk( void ){
 					fseek(btree,8,SEEK_CUR);
 					space_left -= 8;
 				} else
-					fprintf( stderr, "%s: %s/%s: %s\n", PROGNAME, input, "$WWKeywordLinks/BTree", strerror(errno) );
+					fprintf( stderr, "%s: %s/%s: %s\n", PACKAGE, input, "$WWKeywordLinks/BTree", strerror(errno) );
 			}
 
 			/* Go to the next block */
@@ -185,15 +175,15 @@ void recreate_hhk( void ){
 		fputs( SITEMAP_FOOTER, hhk );
 
 		if( ferror(btree) )
-			fprintf( stderr, "%s: %s/%s: %s\n", PROGNAME, input, "$WWKeywordLinks/BTree", strerror(errno) );
+			fprintf( stderr, "%s: %s/%s: %s\n", PACKAGE, input, "$WWKeywordLinks/BTree", strerror(errno) );
 		FCLOSE( btree );
 
 		if( ferror(hhk) )
-			fprintf( stderr, "%s: %s/%s/%s: %s\n", PROGNAME, input, "#recreated", inf, strerror(errno) );
+			fprintf( stderr, "%s: %s/%s/%s: %s\n", PACKAGE, input, "#recreated", inf, strerror(errno) );
 		FCLOSE( hhk );
 
 	} else if( errno && errno != ENOENT )
-		fprintf( stderr, "%s: %s/%s: %s\n", PROGNAME, input, "$WWKeywordLinks/BTree", strerror(errno) );
+		fprintf( stderr, "%s: %s/%s: %s\n", PACKAGE, input, "$WWKeywordLinks/BTree", strerror(errno) );
 
 	close_sitemap();
 }
@@ -214,7 +204,7 @@ char* read_UCS_string(FILE* f,uint* len){
 		/* Get more space */
 		t = (char*)realloc(ret,bytes+GROW*2);
 		if( !t ){
-			fprintf( stderr, "%s: %s %s: %s\n", PROGNAME, input, "$WWKeywordLinks/BTree buffer", strerror(errno) );
+			fprintf( stderr, "%s: %s %s: %s\n", PACKAGE, input, "$WWKeywordLinks/BTree buffer", strerror(errno) );
 			*len = 0; FREE(ret); return NULL;
 		}
 
@@ -222,7 +212,7 @@ char* read_UCS_string(FILE* f,uint* len){
 
 		/* Get more bytes */
 		if( !fread(start,1,GROW*2,f) || ferror(f)){
-			fprintf( stderr, "%s: %s %s: %s\n", PROGNAME, input, "$WWKeywordLinks/BTree", strerror(errno) );
+			fprintf( stderr, "%s: %s %s: %s\n", PACKAGE, input, "$WWKeywordLinks/BTree", strerror(errno) );
 			*len = 0; FREE(ret); return NULL;
 		}
 
