@@ -27,18 +27,6 @@ It was written by Pabs.
 
 
 
-/* System headers */
-
-#include <stdio.h>
-#include <errno.h>
-#include <dirent.h>
-#include <sys/stat.h>
-#include <stdlib.h>
-#include <string.h>
-#include <unistd.h>
-
-
-
 /* Local headers */
 
 #include "chmdeco.h"
@@ -46,7 +34,7 @@ It was written by Pabs.
 #include "convert.h"
 #include "windows.h"
 #include "system.h"
-#include "strings.h"
+#include "strings_file.h"
 #include "sitemap.h"
 #include "misc.h"
 #include "hhp.h"
@@ -109,7 +97,7 @@ void recreate_hhp( void ){
 
 		if( print_blurb )
 			fputs(
-				";This HHP file was recreated by "PROGNAME" "VERSION" (by "AUTHOR" - "WEBSITE")\r\n"
+				";This HHP file was recreated by "PACKAGE" "VERSION" (by "AUTHOR" - "WEBSITE")\r\n"
 				";It is only an approximation of the original project file.\r\n"
 				";Other files that may have been recreated with it are also only approximations.\r\n"
 				";See the documentation for parts of the HHP that cannot be recreated.\r\n\r\n", hhp
@@ -336,8 +324,8 @@ void recreate_hhp( void ){
 			}
 			if(got_lcid){
 				char* Language_string = get_lcid_string( Language );
-				if( Language_string ) fprintf( hhp, "Language=0x%x %s\n", Language, Language_string );
-				else fprintf( hhp, "Language=0x%x\n", Language );
+				if( Language_string ) fprintf( hhp, "Language=0x%x %s\r\n", Language, Language_string );
+				else fprintf( hhp, "Language=0x%x\r\n", Language );
 			}
 		}
 
@@ -351,7 +339,7 @@ void recreate_hhp( void ){
 
 		{ /* Title */
 			char* Title = (char*)get_system( Title_CODE );
-			if( Title ) fprintf( hhp, "Title=%s\n", Title );
+			if( Title ) fprintf( hhp, "Title=%s\r\n", Title );
 			FREE( Title );
 		}
 
@@ -461,16 +449,16 @@ void recreate_hhp( void ){
 					for( i = 0; i < num_subsets; i++ )
 						fprintf( hhp, "There were %u entries in this section, but only garbage was produced\r\n", num_subsets );
 				if( (st.st_size-4)%12 )
-					fprintf( stderr, "%s: warning: %s/%s: %s\n", PROGNAME, input, "#SUBSETS", "partial entry found" );
+					fprintf( stderr, "%s: warning: %s/%s: %s\n", PACKAGE, input, "#SUBSETS", "partial entry found" );
 			}
 		}
 
 		if( !ferror(hhp) ) hhp_success = true;
-		else fprintf( stderr, "%s: %s/%s/%s: %s\n", PROGNAME, input, "#recreated", pf, strerror(errno) );
+		else fprintf( stderr, "%s: %s/%s/%s: %s\n", PACKAGE, input, "#recreated", pf, strerror(errno) );
 
 		FCLOSE( hhp );
 
-	} else fprintf( stderr, "%s: %s/%s/%s: %s\n", PROGNAME, input, "#recreated", pf, strerror(errno) );
+	} else fprintf( stderr, "%s: %s/%s/%s: %s\n", PACKAGE, input, "#recreated", pf, strerror(errno) );
 }
 
 /* Returns true if the argument is the name of an internal file */
@@ -486,20 +474,17 @@ void print_files( char* d ){
 		struct stat st;
 		struct dirent* de;
 
-		/* On *nix we need to enter the dir first */
-#ifndef __MINGW32__
-		chdir( d );
-#endif /* __MINGW32__ */
-
 		while( (de = readdir( dir )) ){
 
+			chdir( d );
+
 			/* Most systems define these as the current & parent dirs */
 			if( !strcmp( de->d_name, "." ) || !strcmp( de->d_name, ".." ) )
-				continue;
+				goto BACKOUT;
 
 			/* Ignore internal files, except when not in root */
 			if( (!prefix || !*prefix) && isinternal(de->d_name) )
-				continue;
+				goto BACKOUT;
 
 			/* Check if it is a subdir */
 			if( !stat( de->d_name, &st ) && S_ISDIR( st.st_mode ) ){
@@ -511,8 +496,8 @@ void print_files( char* d ){
 				if( new_prefix_size > prefix_size ){
 					char* new_prefix = (char*)realloc( prefix, new_prefix_size );
 					if( !new_prefix ){
-						fprintf( stderr, "%s: %s %s: %s\n", PROGNAME, input, "prefix buffer", strerror(errno) );
-						continue;
+						fprintf( stderr, "%s: %s %s: %s\n", PACKAGE, input, "prefix buffer", strerror(errno) );
+						goto BACKOUT;
 					}
 					prefix = new_prefix;
 					prefix_size = new_prefix_size;
@@ -541,13 +526,13 @@ void print_files( char* d ){
 				fprintf( hhp, "%s%s\r\n", prefix?prefix:"", de->d_name );
 
 			}
+
+			/* Back out */
+			BACKOUT:
+				if( !!strcmp( d, "." ) ) chdir( ".." );
 		}
 
-#ifndef __MINGW32__
-		/* Back out */
-		if( !!strcmp( d, "." ) ) chdir( ".." );
-#endif /* __MINGW32__ */
 		closedir( dir );
 	} else
-		fprintf( stderr, "%s: %s/%s/%s: %s\n", PROGNAME, input, prefix?prefix:"", d, strerror(errno) );
+		fprintf( stderr, "%s: %s/%s/%s: %s\n", PACKAGE, input, prefix?prefix:"", d, strerror(errno) );
 }
