@@ -28,25 +28,12 @@ It was written by Pabs.
 
 
 
-/* System headers */
-
-#include <stdio.h>
-#include <errno.h>
-#include <dirent.h>
-#include <sys/stat.h>
-#include <sys/types.h>
-#include <stdlib.h>
-#include <string.h>
-#include <unistd.h>
-
-
-
 /* Local headers */
 
 #include "chmdeco.h"
 #include "common.h"
 #include "sitemap.h"
-#include "strings.h"
+#include "strings_file.h"
 #include "misc.h"
 
 
@@ -112,7 +99,7 @@ void recreate_fts_stop_list_file( void ){
 														}
 
 														if( ferror(stp) )
-															fprintf( stderr, "%s: %s/%s/%s: %s\n", PROGNAME, input, "#recreated", FTS_STOP_LIST_FILE_NAME, strerror(errno) );
+															fprintf( stderr, "%s: %s/%s/%s: %s\n", PACKAGE, input, "#recreated", FTS_STOP_LIST_FILE_NAME, strerror(errno) );
 														else stp_success = true;
 
 														FCLOSE(stp);
@@ -120,8 +107,8 @@ void recreate_fts_stop_list_file( void ){
 														/* We're done */
 														break;
 
-													} else fprintf( stderr, "%s: %s/%s/%s: %s\n", PROGNAME, input, "#recreated", FTS_STOP_LIST_FILE_NAME, strerror(errno) );
-												} else fprintf( stderr, "%s: %s/%s: %s\n", PROGNAME, input, "$OBJINST", strerror(errno) );
+													} else fprintf( stderr, "%s: %s/%s/%s: %s\n", PACKAGE, input, "#recreated", FTS_STOP_LIST_FILE_NAME, strerror(errno) );
+												} else fprintf( stderr, "%s: %s/%s: %s\n", PACKAGE, input, "$OBJINST", strerror(errno) );
 												FREE(buf);
 											} else goto MERROR;
 										}
@@ -138,12 +125,12 @@ void recreate_fts_stop_list_file( void ){
 	return;
 
 FERROR:
-	fprintf( stderr, "%s: %s/%s: %s\n", PROGNAME, input, "$OBJINST", strerror(errno) );
+	fprintf( stderr, "%s: %s/%s: %s\n", PACKAGE, input, "$OBJINST", strerror(errno) );
 	FCLOSE(objinst);
 	return;
 
 MERROR:
-	fprintf( stderr, "%s: %s %s: %s\n", PROGNAME, input, "stp buffer", strerror(errno) );
+	fprintf( stderr, "%s: %s %s: %s\n", PACKAGE, input, "stp buffer", strerror(errno) );
 	FCLOSE(objinst);
 }
 
@@ -182,7 +169,7 @@ void recreate_alias_map( void ){
 						fputs( "\r\n", alias );
 
 					} else if( ferror(ivb) ){
-						fprintf( stderr, "%s: %s/%s: %s\n", PROGNAME, input, "#IVB", strerror(errno) );
+						fprintf( stderr, "%s: %s/%s: %s\n", PACKAGE, input, "#IVB", strerror(errno) );
 						break;
 					}
 
@@ -193,21 +180,21 @@ void recreate_alias_map( void ){
 
 				if( ferror(map) ){
 					alias_map_success =false;
-					fprintf( stderr, "%s: %s/%s/%s: %s\n", PROGNAME, input, "#recreated", MAP_FILE_NAME, strerror(errno) );
+					fprintf( stderr, "%s: %s/%s/%s: %s\n", PACKAGE, input, "#recreated", MAP_FILE_NAME, strerror(errno) );
 				}
 
 				if( ferror(alias) ){
 					alias_map_success =false;
-					fprintf( stderr, "%s: %s/%s/%s: %s\n", PROGNAME, input, "#recreated", ALIAS_FILE_NAME, strerror(errno) );
+					fprintf( stderr, "%s: %s/%s/%s: %s\n", PACKAGE, input, "#recreated", ALIAS_FILE_NAME, strerror(errno) );
 				}
 
 				FCLOSE(map);
-			} else fprintf( stderr, "%s: %s/%s/%s: %s\n", PROGNAME, input, "#recreated", MAP_FILE_NAME, strerror(errno) );
+			} else fprintf( stderr, "%s: %s/%s/%s: %s\n", PACKAGE, input, "#recreated", MAP_FILE_NAME, strerror(errno) );
 			FCLOSE(alias);
-		} else fprintf( stderr, "%s: %s/%s/%s: %s\n", PROGNAME, input, "#recreated", ALIAS_FILE_NAME, strerror(errno) );
+		} else fprintf( stderr, "%s: %s/%s/%s: %s\n", PACKAGE, input, "#recreated", ALIAS_FILE_NAME, strerror(errno) );
 		FCLOSE(ivb);
 	} else if( errno && errno != ENOENT )
-		fprintf( stderr, "%s: %s/%s: %s\n", PROGNAME, input, "#IVB", strerror(errno) );
+		fprintf( stderr, "%s: %s/%s: %s\n", PACKAGE, input, "#IVB", strerror(errno) );
 
 }
 
@@ -216,7 +203,7 @@ char Sample_Staging_Path[8] = "samples";
 
 void recreate_samples( void ){
 	samples_success = false;
-	fprintf( stderr, "%s: warning: %s: %s\n", PROGNAME, input, "samples decompilation not yet implemented" );
+	fprintf( stderr, "%s: warning: %s: %s\n", PACKAGE, input, "samples decompilation not yet implemented" );
 	/*
 	FIXME: Implement this bit
 	DIR* dir = opendir( "." );
@@ -254,6 +241,36 @@ typedef struct _document_t {
 	SRINT earliest_non_title;
 } document_t;
 
+/*
+replacement for mkdir -p
+This needs read-write memory,
+paths containing dir seps / and or \,
+on failure it is evil
+*/
+int mkdirp(char* path){
+	char savec;
+	char* start = path;
+	char* end = start;
+	int numdirs = 0, i;
+	int r = 0;
+	for(;*end;){
+		end = strpbrk( start, "/\\" ); /* Find the next dir end */
+		if( end == start ){ start = ++end; continue; } /* On to the next one if it is a construct like // */
+		if( end == NULL ) break; /* Ignore the filename */
+		savec = *end; *end = '\0'; /* mkdir & chdir need terminater after the name */
+		r = chdir( start ); /* Check if the dir exists */
+		if( r == -1 ){
+			r = mkdir( start, 0777 ); /* Create it if it doesn't */
+			if( r == -1 ) { *end = savec; return -1; } /* Exit if we can't */
+			chdir( start ); /* Enter it if we can */
+		}
+		*end = savec; /* Restore the dir separator */
+		start = ++end; /* And on to the next dir */
+		numdirs++; /* We did another dir */
+	}
+	for( i = 0; i < numdirs; i++ ) chdir( ".." );
+	return 0;
+}
 
 void recreate_html_from_fts( void ){
 	long fts_size;
@@ -262,7 +279,7 @@ void recreate_html_from_fts( void ){
 		if( !fseek( fiftimain, 0, SEEK_END ) && 0 < (fts_size = ftell( fiftimain )) && !fseek( fiftimain, 0, SEEK_SET ) ){
 
 			chdir( "#recreated" );
-			if( !mkdir( "#from-fts" MKDIR_PERM ) || errno == EEXIST ){
+			if( !mkdir( "#from-fts", 0777 ) || errno == EEXIST ){
 
 #define FTS_HEADER_LEN 0x32
 				BYTE header[FTS_HEADER_LEN] = { 0 };
@@ -327,7 +344,7 @@ void recreate_html_from_fts( void ){
 
 				/* Read the header */
 				if( !fread( header, FTS_HEADER_LEN, 1, fiftimain ) ){
-					fprintf( stderr, "%s: %s/%s: %s\n", PROGNAME, input, "$FIftiMain", feof( fiftimain ) ? "unexpected end of file" : strerror(errno) );
+					fprintf( stderr, "%s: %s/%s: %s\n", PACKAGE, input, "$FIftiMain", feof( fiftimain ) ? "unexpected end of file" : strerror(errno) );
 					goto E_MALLOC;
 				}
 
@@ -335,7 +352,7 @@ void recreate_html_from_fts( void ){
 				node_offset = get_DWORD( header + 0x14 );
 
 				if( tmp != node_offset ){
-					fprintf( stderr, "%s: %s/%s: %s\n", PROGNAME, input, "$FIftiMain", "the two root index offsets are not equal, dunno which to trust" );
+					fprintf( stderr, "%s: %s/%s: %s\n", PACKAGE, input, "$FIftiMain", "the two root index offsets are not equal, dunno which to trust" );
 					EMAIL_CHM;
 					goto E_FCLOSE;
 				}
@@ -348,7 +365,7 @@ void recreate_html_from_fts( void ){
 				loc_codes_r = header[0x23];
 
 				if( doc_index_s != 2 || code_count_s != 2 || loc_codes_s != 2 ){
-					fprintf( stderr, "%s: %s/%s: %s\n", PROGNAME, input, "$FIftiMain", "one of the scale parameters has a value other than two, which is not yet supported" );
+					fprintf( stderr, "%s: %s/%s: %s\n", PACKAGE, input, "$FIftiMain", "one of the scale parameters has a value other than two, which is not yet supported" );
 					EMAIL_CHM;
 					goto E_FCLOSE;
 				}
@@ -357,7 +374,7 @@ void recreate_html_from_fts( void ){
 				leaf_node = malloc(node_len);
 
 				if( !leaf_node ){
-					fprintf( stderr, "%s: %s %s: %s\n", PROGNAME, input, "leaf node buffer", strerror(errno) );
+					fprintf( stderr, "%s: %s %s: %s\n", PACKAGE, input, "leaf node buffer", strerror(errno) );
 					goto E_FCLOSE;
 				}
 
@@ -371,12 +388,12 @@ void recreate_html_from_fts( void ){
 					fseek( fiftimain, 2, SEEK_CUR );
 					len = fgetc( fiftimain );
 					if( len == EOF ){
-						fprintf( stderr, "%s: %s/%s: %s\n", PROGNAME, input, "$FIftiMain", feof( fiftimain ) ? "unexpected end of file" : strerror(errno) );
+						fprintf( stderr, "%s: %s/%s: %s\n", PACKAGE, input, "$FIftiMain", feof( fiftimain ) ? "unexpected end of file" : strerror(errno) );
 						goto E_MALLOC;
 					}
 					fseek( fiftimain, (unsigned)len, SEEK_CUR );
 					if( !read_DWORD( fiftimain, &node_offset ) ){
-						fprintf( stderr, "%s: %s/%s: %s\n", PROGNAME, input, "$FIftiMain", feof( fiftimain ) ? "unexpected end of file" : strerror(errno) );
+						fprintf( stderr, "%s: %s/%s: %s\n", PACKAGE, input, "$FIftiMain", feof( fiftimain ) ? "unexpected end of file" : strerror(errno) );
 						goto E_MALLOC;
 					}
 					fseek( fiftimain, node_offset, SEEK_SET );
@@ -386,7 +403,7 @@ void recreate_html_from_fts( void ){
 				for(;;){
 
 					if( !fread( leaf_node, node_len, 1, fiftimain ) ){
-						fprintf( stderr, "%s: %s/%s: %s\n", PROGNAME, input, "$FIftiMain", feof( fiftimain ) ? "unexpected end of file" : strerror(errno) );
+						fprintf( stderr, "%s: %s/%s: %s\n", PACKAGE, input, "$FIftiMain", feof( fiftimain ) ? "unexpected end of file" : strerror(errno) );
 						goto E_MALLOC;
 					}
 
@@ -395,7 +412,7 @@ void recreate_html_from_fts( void ){
 					free_space = get_WORD( leaf_node + 6 );
 
 					if( tmp ){
-						fprintf( stderr, "%s: warning: %s/%s: %s\n", PROGNAME, input, "$FIftiMain", "an unknown field was non-zero" );
+						fprintf( stderr, "%s: warning: %s/%s: %s\n", PACKAGE, input, "$FIftiMain", "an unknown field was non-zero" );
 						EMAIL_CHM;
 					}
 
@@ -409,7 +426,7 @@ void recreate_html_from_fts( void ){
 						old_len = *(offset++);
 
 						if( !word_i && old_len ){
-							fprintf( stderr, "%s: warning: %s/%s: %s\n", PROGNAME, input, "$FIftiMain", "old_len was non-zero at the start of a node" );
+							fprintf( stderr, "%s: warning: %s/%s: %s\n", PACKAGE, input, "$FIftiMain", "old_len was non-zero at the start of a node" );
 							EMAIL_CHM;
 						}
 
@@ -419,7 +436,7 @@ void recreate_html_from_fts( void ){
 							if( new_current_word_size > current_word_size ){
 								char* new_current_word = (char*)realloc(current_word,new_current_word_size);
 								if( !new_current_word ){
-									fprintf( stderr, "%s: %s %s: %s\n", PROGNAME, input, "current word buffer", strerror(errno) );
+									fprintf( stderr, "%s: %s %s: %s\n", PACKAGE, input, "current word buffer", strerror(errno) );
 									goto E_MALLOC;
 								}
 								current_word = new_current_word;
@@ -432,7 +449,7 @@ void recreate_html_from_fts( void ){
 							memcpy( current_word+old_len, offset, new_len-1 );
 							offset += new_len-1;
 						} else {
-							fprintf( stderr, "%s: %s/%s: %s\n", PROGNAME, input, "$FIftiMain", "zero new_len" );
+							fprintf( stderr, "%s: %s/%s: %s\n", PACKAGE, input, "$FIftiMain", "zero new_len" );
 							goto E_MALLOC;
 						}
 						if(old_len+new_len) current_word[old_len+new_len-1] = 0;
@@ -443,7 +460,7 @@ void recreate_html_from_fts( void ){
 							if( new_words_size > words_size ){
 								char** new_words = (char**)realloc(words,sizeof(char*)*new_words_size);
 								if( !new_words ){
-									fprintf( stderr, "%s: %s %s: %s\n", PROGNAME, input, "word array buffer", strerror(errno) );
+									fprintf( stderr, "%s: %s %s: %s\n", PACKAGE, input, "word array buffer", strerror(errno) );
 									goto E_MALLOC;
 								}
 								words = new_words;
@@ -455,13 +472,13 @@ void recreate_html_from_fts( void ){
 						/* Store the current word */
 						words[words_len-1] = strdup(current_word);
 						if( !words[words_len-1] ){
-							fprintf( stderr, "%s: %s %s: %s\n", PROGNAME, input, "word buffer", strerror(errno) );
+							fprintf( stderr, "%s: %s %s: %s\n", PACKAGE, input, "word buffer", strerror(errno) );
 							goto E_MALLOC;
 						}
 
 						context = *(offset++);
 						if( context != 0 && context != 1 ){
-							fprintf( stderr, "%s: warning: %s/%s: %s\n", PROGNAME, input, "$FIftiMain", "unknown context" );
+							fprintf( stderr, "%s: warning: %s/%s: %s\n", PACKAGE, input, "$FIftiMain", "unknown context" );
 							EMAIL_CHM;
 						}
 
@@ -469,7 +486,7 @@ void recreate_html_from_fts( void ){
 						wlc_offset = get_DWORD( offset ); offset += 4;
 						tmp = get_WORD( offset ); offset += 2;
 						if( tmp ){
-							fprintf( stderr, "%s: warning: %s/%s: %s\n", PROGNAME, input, "$FIftiMain", "an unknown field was non-zero" );
+							fprintf( stderr, "%s: warning: %s/%s: %s\n", PACKAGE, input, "$FIftiMain", "an unknown field was non-zero" );
 							EMAIL_CHM;
 						}
 						wlc_length = get_be_ENCINT( &offset );
@@ -480,7 +497,7 @@ void recreate_html_from_fts( void ){
 							if( new_word_location_codes_size > word_location_codes_size ){
 								BYTE* new_word_location_codes = (BYTE*)realloc(word_location_codes,new_word_location_codes_size);
 								if( !new_word_location_codes ){
-									fprintf( stderr, "%s: %s %s: %s\n", PROGNAME, input, "encoded word locations buffer", strerror(errno) );
+									fprintf( stderr, "%s: %s %s: %s\n", PACKAGE, input, "encoded word locations buffer", strerror(errno) );
 									goto E_MALLOC;
 								}
 								word_location_codes = new_word_location_codes;
@@ -491,7 +508,7 @@ void recreate_html_from_fts( void ){
 
 						fseek( fiftimain, wlc_offset,  SEEK_SET );
 						if( !fread( word_location_codes, wlc_length, 1, fiftimain ) ){
-							fprintf( stderr, "%s: %s/%s: %s\n", PROGNAME, input, "$FIftiMain", feof( fiftimain ) ? "unexpected end of file" : strerror(errno) );
+							fprintf( stderr, "%s: %s/%s: %s\n", PACKAGE, input, "$FIftiMain", feof( fiftimain ) ? "unexpected end of file" : strerror(errno) );
 							goto E_MALLOC;
 						}
 
@@ -514,7 +531,7 @@ void recreate_html_from_fts( void ){
 								if( new_docs_size > docs_size ){
 									document_t* new_docs = (document_t*)realloc(docs,sizeof(document_t)*new_docs_size);
 									if( !new_docs ){
-										fprintf( stderr, "%s: %s %s: %s\n", PROGNAME, input, "document array buffer", strerror(errno) );
+										fprintf( stderr, "%s: %s %s: %s\n", PACKAGE, input, "document array buffer", strerror(errno) );
 										goto E_MALLOC;
 									}
 									docs = new_docs;
@@ -543,7 +560,7 @@ void recreate_html_from_fts( void ){
 									if( new_words_size > docs[document_index].words_size ){
 										char** new_words = (char**)realloc(docs[document_index].words,sizeof(char*)*new_words_size);
 										if( !new_words ){
-											fprintf( stderr, "%s: %s %s: %s\n", PROGNAME, input, "document word array buffer", strerror(errno) );
+											fprintf( stderr, "%s: %s %s: %s\n", PACKAGE, input, "document word array buffer", strerror(errno) );
 											goto E_MALLOC;
 										}
 										docs[document_index].words = new_words;
@@ -592,7 +609,7 @@ void recreate_html_from_fts( void ){
 						if( !docs[docs_i].words ) continue;
 
 						if( docs[docs_i].earliest_non_title != ~(SRINT)0 && docs[docs_i].latest_title != ~(SRINT)0 && docs[docs_i].earliest_non_title <= docs[docs_i].latest_title ){
-							fprintf( stderr, "%s: warning: %s/%s: %s\n", PROGNAME, input, "$FIftiMain", "a document had overlapping title & body" );
+							fprintf( stderr, "%s: warning: %s/%s: %s\n", PACKAGE, input, "$FIftiMain", "a document had overlapping title & body" );
 							EMAIL_CHM;
 						}
 
@@ -611,6 +628,7 @@ void recreate_html_from_fts( void ){
 							out_file = entry;
 						}
 
+						mkdirp( out_file );
 						f = fopen( out_file, "wb" );
 						if( f ){
 
@@ -643,11 +661,13 @@ void recreate_html_from_fts( void ){
 							fputs( "</html>", f );
 
 							if( ferror( f ) | feof( f ) ){
-								fprintf( stderr, "%s: %s/%s: %s\n", PROGNAME, input, "$FIftiMain", feof( fiftimain ) ? "unexpected end of file" : strerror(errno) );
+								fprintf( stderr, "%s: %s/%s: %s\n", PACKAGE, input, "$FIftiMain", feof( fiftimain ) ? "unexpected end of file" : strerror(errno) );
 							}
 
 							fclose( f );
 							f = NULL;
+						} else {
+							fprintf( stderr, "%s: warning: %s: %s\n", PACKAGE, out_file, strerror(errno) );
 						}
 
 						FREE(docs[docs_i].words);
@@ -675,6 +695,6 @@ E_MALLOC:
 E_FCLOSE:
 		fclose( fiftimain );
 	} else if( errno && errno != ENOENT )
-		fprintf( stderr, "%s: %s/%s: %s\n", PROGNAME, input, "$FIftiMain", strerror(errno) );
+		fprintf( stderr, "%s: %s/%s: %s\n", PACKAGE, input, "$FIftiMain", strerror(errno) );
 
 }
