@@ -27,23 +27,13 @@ It was written by Pabs.
 
 
 
-/* System headers */
-
-#include <stdio.h>
-#include <sys/types.h>
-#include <stdlib.h>
-#include <string.h>
-#include <errno.h>
-
-
-
 /* Local headers */
 
 #include "chmdeco.h"
 #include "common.h"
 #include "convert.h"
 #include "sitemap.h"
-#include "strings.h"
+#include "strings_file.h"
 
 
 
@@ -59,17 +49,17 @@ bool open_sitemap(){
 		errno = 0;
 		topics = fopen( "#TOPICS", "rb" );
 		if( !topics && errno && errno != ENOENT )
-			fprintf( stderr, "%s: %s/%s: %s\n", PROGNAME, input, "#TOPICS", strerror(errno) );
+			fprintf( stderr, "%s: %s/%s: %s\n", PACKAGE, input, "#TOPICS", strerror(errno) );
 
 		errno = 0;
 		urltbl = fopen( "#URLTBL", "rb" );
 		if( !urltbl && errno && errno != ENOENT )
-			fprintf( stderr, "%s: %s/%s: %s\n", PROGNAME, input, "#URLTBL", strerror(errno) );
+			fprintf( stderr, "%s: %s/%s: %s\n", PACKAGE, input, "#URLTBL", strerror(errno) );
 
 		errno = 0;
 		urlstr = fopen( "#URLSTR", "rb" );
 		if( !urlstr && errno && errno != ENOENT )
-			fprintf( stderr, "%s: %s/%s: %s\n", PROGNAME, input, "#URLSTR", strerror(errno) );
+			fprintf( stderr, "%s: %s/%s: %s\n", PACKAGE, input, "#URLSTR", strerror(errno) );
 
 		if( topics && urltbl && urlstr ){
 			return true;
@@ -99,7 +89,7 @@ char* get_urlstr(off_t off){
 		/* Get more space */
 		t = (char*)realloc(ret,ret_len+GROW);
 		if( !t ){
-			fprintf( stderr, "%s: %s %s: %s\n", PROGNAME, input, "#URLSTR buffer", strerror(errno) );
+			fprintf( stderr, "%s: %s %s: %s\n", PACKAGE, input, "#URLSTR buffer", strerror(errno) );
 			FREE(ret);
 			return NULL;
 		}
@@ -108,7 +98,7 @@ char* get_urlstr(off_t off){
 
 		/* Get more bytes */
 		if( !fread(start,1,GROW,urlstr) || ferror(urlstr) ){
-			fprintf( stderr, "%s: %s/%s: %s\n", PROGNAME, input, "#URLSTR", strerror(errno) );
+			fprintf( stderr, "%s: %s/%s: %s\n", PACKAGE, input, "#URLSTR", strerror(errno) );
 			FREE(ret);
 			return NULL;
 		}
@@ -185,9 +175,9 @@ bool print_topics_entry( FILE* f, size_t index ){
 				}
 
 				return true;
-			} else fprintf( stderr, "%s: %s/%s: %s\n", PROGNAME, input, "#URLSTR", strerror(errno) );
-		} else fprintf( stderr, "%s: %s/%s: %s\n", PROGNAME, input, "#URLTBL", strerror(errno) );
-	} else fprintf( stderr, "%s: %s/%s: %s\n", PROGNAME, input, "#TOPICS", strerror(errno) );
+			} else fprintf( stderr, "%s: %s/%s: %s\n", PACKAGE, input, "#URLSTR", strerror(errno) );
+		} else fprintf( stderr, "%s: %s/%s: %s\n", PACKAGE, input, "#URLTBL", strerror(errno) );
+	} else fprintf( stderr, "%s: %s/%s: %s\n", PACKAGE, input, "#TOPICS", strerror(errno) );
 
 	return false;
 }
@@ -204,10 +194,10 @@ DWORD find_in_urltbl( DWORD majik ){
 		len = fread( buf, 1, 4096, urltbl );
 
 		if( len < 4096 && len%12 )
-			fprintf( stderr, "%s: warning: %s/%s: %s\n", PROGNAME, input, "#URLTBL", "partial entry found" );
+			fprintf( stderr, "%s: warning: %s/%s: %s\n", PACKAGE, input, "#URLTBL", "partial entry found" );
 
 		if( ferror(urltbl) || errno )
-			fprintf( stderr, "%s: %s/%s: %s\n", PROGNAME, input, "#URLTBL", strerror(errno) );
+			fprintf( stderr, "%s: %s/%s: %s\n", PACKAGE, input, "#URLTBL", strerror(errno) );
 
 		/* We only want complete entries */
 		len = len/12*12;
