@@ -27,26 +27,16 @@ It was written by Pabs.
 
 
 
-/* System headers */
-
-#include <stdio.h>
-#include <sys/types.h>
-#include <errno.h>
-#include <stdlib.h>
-#include <string.h>
-
-
-
 /* Local headers */
 
+#include "common.h"
+#include "chmdeco.h"
+#include "strings_file.h"
+
 
 
-#include "chmdeco.h"
-#include "common.h"
-#include "strings.h"
-
-/* FIXME: Use the blockiness of this file (and the fact that no string crosses the
-boundary) to our advantage */
+/* FIXME: Use the blockiness of this file (and the fact that no string crosses
+the boundary) to our advantage */
 
 #define BUF_LEN 4096
 
@@ -84,7 +74,7 @@ bool open_strings( void ){
 	}
 
 	/* The #STRINGS file is essential, so always print */
-	fprintf( stderr, "%s: %s/%s: %s\n", PROGNAME, input, "#STRINGS", strerror(errno) );
+	fprintf( stderr, "%s: %s/%s: %s\n", PACKAGE, input, "#STRINGS", strerror(errno) );
 
 	return false;
 }
@@ -125,7 +115,7 @@ bool print_string( FILE* f, off_t off ){
 
 			if( !string_buf_len ) return true;
 			else if( ferror(strings) ){
-				fprintf( stderr, "%s: %s/%s: %s\n", PROGNAME, input, "#STRINGS", strerror(errno) );
+				fprintf( stderr, "%s: %s/%s: %s\n", PACKAGE, input, "#STRINGS", strerror(errno) );
 				return false;
 			}
 		}
@@ -164,7 +154,7 @@ char* get_string( off_t off ){
 					ret_length += length;
 					strcpy( ret_start, start );
 				} else {
-					fprintf( stderr, "%s: %s %s: %s\n", PROGNAME, input, "#STRINGS buffer", strerror(errno) );
+					fprintf( stderr, "%s: %s %s: %s\n", PACKAGE, input, "#STRINGS buffer", strerror(errno) );
 					FREE( ret ); return NULL;
 				}
 
@@ -178,7 +168,7 @@ char* get_string( off_t off ){
 
 			if( !string_buf_len ) return ret;
 			else if( ferror(strings) ){
-				fprintf( stderr, "%s: %s/%s: %s\n", PROGNAME, input, "#STRINGS", strerror(errno) );
+				fprintf( stderr, "%s: %s/%s: %s\n", PACKAGE, input, "#STRINGS", strerror(errno) );
 				FREE( ret ); return NULL;
 			}
 		}
