@@ -27,15 +27,6 @@ It was written by Pabs.
 
 
 
-/* System headers */
-
-#include <stdio.h>
-#include <errno.h>
-#include <stdlib.h>
-#include <string.h>
-
-
-
 /* Local headers */
 
 #include "chmdeco.h"
@@ -74,7 +65,7 @@ bool open_system( void ){
 					system_entries[code].length = length;
 					system_entries[code].offset = ftell(system_file);
 				} else {
-					fprintf( stderr, "%s: warning: %s/%s: %s\n", PROGNAME, input, "#SYSTEM", "unknown entry code found" );
+					fprintf( stderr, "%s: warning: %s/%s: %s\n", PACKAGE, input, "#SYSTEM", "unknown entry code found" );
 					EMAIL_CHM;
 				}
 				fseek(system_file, length, SEEK_CUR);
@@ -86,7 +77,7 @@ bool open_system( void ){
 		}
 	}
 ERROR:
-	if( errno != ENOENT ) fprintf( stderr, "%s: %s/%s: %s\n", PROGNAME, input, "#SYSTEM", strerror(errno) );
+	if( errno != ENOENT ) fprintf( stderr, "%s: %s/%s: %s\n", PACKAGE, input, "#SYSTEM", strerror(errno) );
 	FCLOSE(system_file);
 	return false;
 }
@@ -94,7 +85,7 @@ ERROR:
 BYTE* get_system(WORD code){
 
 	if( code >= MAX_CODE ){
-		fprintf( stderr, "%s: bug: %s/%s: invalid code accessed (%u)\n", PROGNAME, input, "#SYSTEM", code );
+		fprintf( stderr, "%s: bug: %s/%s: invalid code accessed (%u)\n", PACKAGE, input, "#SYSTEM", code );
 		return NULL;
 	}
 
@@ -107,11 +98,11 @@ BYTE* get_system(WORD code){
 			ret[system_entries[code].length]=0;
 			fseek(system_file, system_entries[code].offset, SEEK_SET);
 			if( !fread( ret, system_entries[code].length, 1, system_file) ){
-				fprintf( stderr, "%s: %s/%s: %s\n", PROGNAME, input, "#SYSTEM", strerror(errno) );
+				fprintf( stderr, "%s: %s/%s: %s\n", PACKAGE, input, "#SYSTEM", strerror(errno) );
 				FREE(ret);
 			}
 
-		} else fprintf( stderr, "%s: %s/%s: %s\n", PROGNAME, input, "#SYSTEM buffer", strerror(errno) );
+		} else fprintf( stderr, "%s: %s/%s: %s\n", PACKAGE, input, "#SYSTEM buffer", strerror(errno) );
 		return ret;
 
 	}
@@ -120,7 +111,7 @@ BYTE* get_system(WORD code){
 bool get_system_DWORD(WORD code, DWORD* d){
 
 	if( code >= MAX_CODE ){
-		fprintf( stderr, "%s: bug: %s/%s: invalid code accessed (%u)\n", PROGNAME, input, "#SYSTEM", code );
+		fprintf( stderr, "%s: bug: %s/%s: invalid code accessed (%u)\n", PACKAGE, input, "#SYSTEM", code );
 		return false;
 	}
 
@@ -130,11 +121,11 @@ bool get_system_DWORD(WORD code, DWORD* d){
 		bool ret;
 		fseek(system_file, system_entries[code].offset, SEEK_SET);
 		ret = read_DWORD( system_file, d );
-		if(!ret) fprintf( stderr, "%s: %s/%s: %s\n", PROGNAME, input, "#SYSTEM", strerror(errno) );
+		if(!ret) fprintf( stderr, "%s: %s/%s: %s\n", PACKAGE, input, "#SYSTEM", strerror(errno) );
 		return ret;
 
 	} else {
-		fprintf( stderr, "%s: bug: %s/%s: %s\n", PROGNAME, input, "#SYSTEM", "entry too small" );
+		fprintf( stderr, "%s: bug: %s/%s: %s\n", PACKAGE, input, "#SYSTEM", "entry too small" );
 		return false;
 	}
 }
@@ -142,19 +133,19 @@ bool get_system_DWORD(WORD code, DWORD* d){
 bool get_system_to(WORD code, BYTE* buf, WORD length){
 
 	if( code >= MAX_CODE ){
-		fprintf( stderr, "%s: bug: %s/%s: invalid code accessed (%u)\n", PROGNAME, input, "#SYSTEM", code );
+		fprintf( stderr, "%s: bug: %s/%s: invalid code accessed (%u)\n", PACKAGE, input, "#SYSTEM", code );
 		return false;
 	}
 
 	if( system_entries[code].offset < 0 ){
 		if( length < system_entries[code].length )
-			fprintf( stderr, "%s: bug: %s/%s: %s\n", PROGNAME, input, "#SYSTEM", "not enough storage in buffer" );
+			fprintf( stderr, "%s: bug: %s/%s: %s\n", PACKAGE, input, "#SYSTEM", "not enough storage in buffer" );
 		return false;
 	} else {
 		bool ret;
 		fseek(system_file, system_entries[code].offset, SEEK_SET);
 		ret = fread( buf, system_entries[code].length, 1, system_file) ? true : false;
-		if(!ret) fprintf( stderr, "%s: %s/%s: %s\n", PROGNAME, input, "#SYSTEM", strerror(errno) );
+		if(!ret) fprintf( stderr, "%s: %s/%s: %s\n", PACKAGE, input, "#SYSTEM", strerror(errno) );
 		return ret;
 	}
 }
